@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-
 from importlib import import_module
 
 from django.conf import settings
@@ -27,12 +25,15 @@ class CoopBar:
                         loader_fct = getattr(app_admin_bar_module, 'load_commands')
                         loader_fct(self)
                     except ImportError as msg:
-                        raise ImportError("coop_bar : error while loading '{0}': {1}".format(module_name, msg))
+                        text = "coop_bar : error while loading '{0}': {1}".format(module_name, msg)
+                        raise ImportError(text)
+                    except Exception as msg2:
+                        raise
             else:
                 for app in settings.INSTALLED_APPS:
                     try:
                         # load dynamically the admin_bar module of all apps
-                        app_admin_bar_module = import_module(app+'.coop_bar_cfg')
+                        app_admin_bar_module = import_module(app + '.coop_bar_cfg')
                         if hasattr(app_admin_bar_module, 'load_commands'):
                             # call the load_commands function in this module
                             # This function should call the AdminBar:register_command for
