@@ -1,15 +1,13 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-
 from django import template
 from django.conf import settings
 from django.template.loader import get_template
-from django.utils.text import mark_safe
+from django.utils.safestring import mark_safe
 
-from coop_bar import get_version
-from coop_bar.bar import CoopBar
-from coop_bar.utils import context_to_dict
+from .. import get_version
+from ..bar import CoopBar
+from ..utils import context_to_dict
 
 register = template.Library()
 
@@ -51,7 +49,12 @@ class CoopBarHeaderNode(template.Node):
         url = '<link rel="stylesheet" href="{0}css/coop_bar.css?v={1}" type="text/css" />'.format(
             static_url, get_version()
         )
-        headers = [mark_safe(url), mark_safe('<link rel="stylesheet" href="{0}fontawesome/css/all.css" type="text/css" />'.format(static_url))]
+        headers = [
+            mark_safe(url),
+            # mark_safe(
+            #   '<link rel="stylesheet" href="{0}fontawesome/css/all.css" type="text/css" />'.format(static_url)
+            # )
+        ]
         headers += CoopBar().get_headers(request, context_to_dict(context))
         return "\n".join(headers)
 
