@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-
-from coop_bar.bar import CoopBar
+from .bar import CoopBar
 
 urlpatterns = []
 
